#ifndef MATRIX_H
#define MATRIX_H

#include "vector.h"

/**
 * @author Alexander Lang
 */
class Matrix
{
public:
    enum Axis
    {
        X,Y,Z
    };

    Matrix();
    Matrix(GLdouble* mat);
    Matrix(const Vector& right, const Vector& up, const Vector& forward);
    ~Matrix();

    void rotate(float degrees, Axis axis);
    void rotate(float degrees, const Vector& v);
    void scale(const Vector& v);
    void translate(const Vector& v);

    Vector operator* (const Vector& v) const;

    void mult(Matrix& other);
    Vector right() const;
    Vector up() const;
    Vector forward() const;
    Vector translation() const;
    void debugPrint() const;

    float* get();

    void euler(float* x, float* y, float* z) const;

    static Matrix fromViewDir(const Vector& v);
private:
    float mat[16];

    void setIdentity();
    void matrixMult(float* otherMat);

};

#endif // MATRIX_H
